#!/bin/bash

LOG_DIR=$HOME
LOG_FILE="${LOG_DIR}/.fly-monitor-sensor.log"
NAME=`basename $0`
LOCK_FILE="/tmp/$NAME-${DISPLAY}.lock"

function terminate() {
	rm -f $LOCK_FILE
	pkill inotifywait
	pkill monitor-sensor
	exit 1
}

trap terminate INT TERM HUP KILL

#nothing to do
if [ ! -f /usr/bin/inotifywait ] ; then exit; fi
if [ ! -f /usr/bin/monitor-sensor ] ; then exit; fi

#lock
copy=`ps h -C $NAME | grep -v $$ | wc -l`

if [ $copy -gt 1 ] ; then
	[ -f $LOCK_FILE ] && exit
fi
echo $$ > $LOCK_FILE

# Launch monitor-sensor and store the output in a variable that can be parsed by the rest of the script
> $LOG_FILE
/usr/bin/monitor-sensor >> $LOG_FILE 2>&1 &

while /usr/bin/inotifywait -e modify $LOG_FILE > /dev/null 2>&1; do
    xset q | grep "Monitor is Off" > /dev/null 2>&1
    if [ $? -eq "0" ]; then continue; fi

    ORIENTATION=$(tail -n 1 $LOG_FILE | grep 'orientation' | grep -oE '[^ ]+$')
    case "$ORIENTATION" in
    normal)
      fly-rotate.sh normal ;;
    bottom-up)
      fly-rotate.sh inverted ;;
    right-up)
      fly-rotate.sh right  ;;
    left-up)
      fly-rotate.sh left ;;
    esac
done

terminate
